@@ -1,5 +1,5 @@
 // Ceres Solver - A fast non-linear least squares minimizer
-// Copyright 2015 Google Inc. All rights reserved.
+// Copyright 2023 Google Inc. All rights reserved.
 // http://ceres-solver.org/
 //
 // Redistribution and use in source and binary forms, with or without
@@ -50,76 +50,79 @@
 // A problem is considered solved if of the log relative error of its
 // objective function is at least 4.
 
-
 #include <cmath>
 #include <iostream>  // NOLINT
 #include <sstream>   // NOLINT
 #include <string>
+
 #include "ceres/ceres.h"
 #include "gflags/gflags.h"
 #include "glog/logging.h"
 
 DEFINE_string(problem, "all", "Which problem to solve");
-DEFINE_bool(use_numeric_diff, false,
-            "Use numeric differentiation instead of automatic "
-            "differentiation.");
-DEFINE_string(numeric_diff_method, "ridders", "When using numeric "
-              "differentiation, selects algorithm. Options are: central, "
-              "forward, ridders.");
-DEFINE_int32(ridders_extrapolations, 3, "Maximal number of extrapolations in "
-             "Ridders' method.");
+DEFINE_bool(use_numeric_diff,
+            false,
+            "Use numeric differentiation instead of automatic"
+            " differentiation.");
+DEFINE_string(numeric_diff_method,
+              "ridders",
+              "When using numeric differentiation, selects algorithm. Options "
+              "are: central, forward, ridders.");
+DEFINE_int32(ridders_extrapolations,
+             3,
+             "Maximal number of extrapolations in Ridders' method.");
 
-namespace ceres {
-namespace examples {
+namespace ceres::examples {
 
 const double kDoubleMax = std::numeric_limits<double>::max();
 
 static void SetNumericDiffOptions(ceres::NumericDiffOptions* options) {
-  options->max_num_ridders_extrapolations = FLAGS_ridders_extrapolations;
+  options->max_num_ridders_extrapolations =
+      CERES_GET_FLAG(FLAGS_ridders_extrapolations);
 }
 
-#define BEGIN_MGH_PROBLEM(name, num_parameters, num_residuals)            \
-  struct name {                                                           \
-    static const int kNumParameters = num_parameters;                     \
-    static const double initial_x[kNumParameters];                        \
-    static const double lower_bounds[kNumParameters];                     \
-    static const double upper_bounds[kNumParameters];                     \
-    static const double constrained_optimal_cost;                         \
-    static const double unconstrained_optimal_cost;                       \
-    static CostFunction* Create() {                                       \
-      if (FLAGS_use_numeric_diff) {                                       \
-        ceres::NumericDiffOptions options;                                \
-        SetNumericDiffOptions(&options);                                  \
-        if (FLAGS_numeric_diff_method == "central") {                     \
-          return new NumericDiffCostFunction<name,                        \
-                                             ceres::CENTRAL,              \
-                                             num_residuals,               \
-                                             num_parameters>(             \
-              new name, ceres::TAKE_OWNERSHIP, num_residuals, options);   \
-        } else if (FLAGS_numeric_diff_method == "forward") {              \
-          return new NumericDiffCostFunction<name,                        \
-                                             ceres::FORWARD,              \
-                                             num_residuals,               \
-                                             num_parameters>(             \
-              new name, ceres::TAKE_OWNERSHIP, num_residuals, options);   \
-        } else if (FLAGS_numeric_diff_method == "ridders") {              \
-          return new NumericDiffCostFunction<name,                        \
-                                             ceres::RIDDERS,              \
-                                             num_residuals,               \
-                                             num_parameters>(             \
-              new name, ceres::TAKE_OWNERSHIP, num_residuals, options);   \
-        } else {                                                          \
-          LOG(ERROR) << "Invalid numeric diff method specified";          \
-          return NULL;                                                    \
-        }                                                                 \
-      } else {                                                            \
-        return new AutoDiffCostFunction<name,                             \
-                                        num_residuals,                    \
-                                        num_parameters>(new name);        \
-      }                                                                   \
-    }                                                                     \
-    template <typename T>                                                 \
+#define BEGIN_MGH_PROBLEM(name, num_parameters, num_residuals)                \
+  struct name {                                                               \
+    static constexpr int kNumParameters = num_parameters;                     \
+    static const double initial_x[kNumParameters];                            \
+    static const double lower_bounds[kNumParameters];                         \
+    static const double upper_bounds[kNumParameters];                         \
+    static const double constrained_optimal_cost;                             \
+    static const double unconstrained_optimal_cost;                           \
+    static CostFunction* Create() {                                           \
+      if (CERES_GET_FLAG(FLAGS_use_numeric_diff)) {                           \
+        ceres::NumericDiffOptions options;                                    \
+        SetNumericDiffOptions(&options);                                      \
+        if (CERES_GET_FLAG(FLAGS_numeric_diff_method) == "central") {         \
+          return new NumericDiffCostFunction<name,                            \
+                                             ceres::CENTRAL,                  \
+                                             num_residuals,                   \
+                                             num_parameters>(                 \
+              new name, ceres::TAKE_OWNERSHIP, num_residuals, options);       \
+        } else if (CERES_GET_FLAG(FLAGS_numeric_diff_method) == "forward") {  \
+          return new NumericDiffCostFunction<name,                            \
+                                             ceres::FORWARD,                  \
+                                             num_residuals,                   \
+                                             num_parameters>(                 \
+              new name, ceres::TAKE_OWNERSHIP, num_residuals, options);       \
+        } else if (CERES_GET_FLAG(FLAGS_numeric_diff_method) == "ridders") {  \
+          return new NumericDiffCostFunction<name,                            \
+                                             ceres::RIDDERS,                  \
+                                             num_residuals,                   \
+                                             num_parameters>(                 \
+              new name, ceres::TAKE_OWNERSHIP, num_residuals, options);       \
+        } else {                                                              \
+          LOG(ERROR) << "Invalid numeric diff method specified";              \
+          return nullptr;                                                     \
+        }                                                                     \
+      } else {                                                                \
+        return new AutoDiffCostFunction<name, num_residuals, num_parameters>( \
+            new name);                                                        \
+      }                                                                       \
+    }                                                                         \
+    template <typename T>                                                     \
     bool operator()(const T* const x, T* residual) const {
+// clang-format off
 
 #define END_MGH_PROBLEM return true; } };  // NOLINT
 
@@ -220,7 +223,7 @@ BEGIN_MGH_PROBLEM(TestProblem7, 3, 3)
   const T x1 = x[0];
   const T x2 = x[1];
   const T x3 = x[2];
-  const T theta = (0.5 / M_PI)  * atan(x2 / x1) + (x1 > 0.0 ? 0.0 : 0.5);
+  const T theta = (0.5 / constants::pi)  * atan(x2 / x1) + (x1 > 0.0 ? 0.0 : 0.5);
   residual[0] = 10.0 * (x3 - 10.0 * theta);
   residual[1] = 10.0 * (sqrt(x1 * x1 + x2 * x2) - 1.0);
   residual[2] = x3;
@@ -535,14 +538,17 @@ const double TestProblem19::unconstrained_optimal_cost = 4.01377e-2;
 #undef BEGIN_MGH_PROBLEM
 #undef END_MGH_PROBLEM
 
-template<typename TestProblem> bool Solve(bool is_constrained, int trial) {
+// clang-format on
+
+template <typename TestProblem>
+bool Solve(bool is_constrained, int trial) {
   double x[TestProblem::kNumParameters];
   for (int i = 0; i < TestProblem::kNumParameters; ++i) {
     x[i] = pow(10, trial) * TestProblem::initial_x[i];
   }
 
   Problem problem;
-  problem.AddResidualBlock(TestProblem::Create(), NULL, x);
+  problem.AddResidualBlock(TestProblem::Create(), nullptr, x);
   double optimal_cost = TestProblem::unconstrained_optimal_cost;
 
   if (is_constrained) {
@@ -563,26 +569,22 @@ template<typename TestProblem> bool Solve(bool is_constrained, int trial) {
   Solve(options, &problem, &summary);
 
   const double kMinLogRelativeError = 4.0;
-  const double log_relative_error = -std::log10(
-      std::abs(2.0 * summary.final_cost - optimal_cost) /
-      (optimal_cost > 0.0 ? optimal_cost : 1.0));
+  const double log_relative_error =
+      -std::log10(std::abs(2.0 * summary.final_cost - optimal_cost) /
+                  (optimal_cost > 0.0 ? optimal_cost : 1.0));
 
   const bool success = log_relative_error >= kMinLogRelativeError;
-  LOG(INFO) << "Expected : " <<  optimal_cost
-            << " actual: " << 2.0 * summary.final_cost
-            << " " << success
-            << " in " << summary.total_time_in_seconds
-            << " seconds";
+  LOG(INFO) << "Expected : " << optimal_cost
+            << " actual: " << 2.0 * summary.final_cost << " " << success
+            << " in " << summary.total_time_in_seconds << " seconds";
   return success;
 }
 
-}  // namespace examples
-}  // namespace ceres
+}  // namespace ceres::examples
 
 int main(int argc, char** argv) {
-  CERES_GFLAGS_NAMESPACE::ParseCommandLineFlags(&argc, &argv, true);
+  GFLAGS_NAMESPACE::ParseCommandLineFlags(&argc, &argv, true);
   google::InitGoogleLogging(argv[0]);
-
   using ceres::examples::Solve;
 
   int unconstrained_problems = 0;
@@ -591,29 +593,30 @@ int main(int argc, char** argv) {
   int constrained_successes = 0;
   std::stringstream ss;
 
-#define UNCONSTRAINED_SOLVE(n)                                          \
-  ss << "Unconstrained Problem " << n << " : ";                          \
-  if (FLAGS_problem == #n || FLAGS_problem == "all") {                  \
-    unconstrained_problems += 3;                                        \
-    if (Solve<ceres::examples::TestProblem##n>(false, 0)) {             \
-      unconstrained_successes += 1;                                     \
-      ss <<  "Yes ";                                                    \
-    } else {                                                            \
-      ss << "No  ";                                                     \
-    }                                                                   \
-    if (Solve<ceres::examples::TestProblem##n>(false, 1)) {             \
-      unconstrained_successes += 1;                                     \
-      ss << "Yes ";                                                     \
-    } else {                                                            \
-      ss << "No  ";                                                     \
-    }                                                                   \
-    if (Solve<ceres::examples::TestProblem##n>(false, 2)) {             \
-      unconstrained_successes += 1;                                     \
-      ss << "Yes ";                                                     \
-    } else {                                                            \
-      ss << "No  ";                                                     \
-    }                                                                   \
-  }                                                                     \
+#define UNCONSTRAINED_SOLVE(n)                              \
+  ss << "Unconstrained Problem " << n << " : ";             \
+  if (CERES_GET_FLAG(FLAGS_problem) == #n ||                \
+      CERES_GET_FLAG(FLAGS_problem) == "all") {             \
+    unconstrained_problems += 3;                            \
+    if (Solve<ceres::examples::TestProblem##n>(false, 0)) { \
+      unconstrained_successes += 1;                         \
+      ss << "Yes ";                                         \
+    } else {                                                \
+      ss << "No  ";                                         \
+    }                                                       \
+    if (Solve<ceres::examples::TestProblem##n>(false, 1)) { \
+      unconstrained_successes += 1;                         \
+      ss << "Yes ";                                         \
+    } else {                                                \
+      ss << "No  ";                                         \
+    }                                                       \
+    if (Solve<ceres::examples::TestProblem##n>(false, 2)) { \
+      unconstrained_successes += 1;                         \
+      ss << "Yes ";                                         \
+    } else {                                                \
+      ss << "No  ";                                         \
+    }                                                       \
+  }                                                         \
   ss << std::endl;
 
   UNCONSTRAINED_SOLVE(1);
@@ -636,22 +639,21 @@ int main(int argc, char** argv) {
   UNCONSTRAINED_SOLVE(18);
   UNCONSTRAINED_SOLVE(19);
 
-  ss << "Unconstrained : "
-     << unconstrained_successes
-     << "/"
+  ss << "Unconstrained : " << unconstrained_successes << "/"
      << unconstrained_problems << std::endl;
 
-#define CONSTRAINED_SOLVE(n)                                            \
-  ss << "Constrained Problem " << n << " : ";                           \
-  if (FLAGS_problem == #n || FLAGS_problem == "all") {                  \
-    constrained_problems += 1;                                          \
-    if (Solve<ceres::examples::TestProblem##n>(true, 0)) {              \
-      constrained_successes += 1;                                       \
-      ss << "Yes ";                                                     \
-    } else {                                                            \
-      ss << "No  ";                                                     \
-    }                                                                   \
-  }                                                                     \
+#define CONSTRAINED_SOLVE(n)                               \
+  ss << "Constrained Problem " << n << " : ";              \
+  if (CERES_GET_FLAG(FLAGS_problem) == #n ||               \
+      CERES_GET_FLAG(FLAGS_problem) == "all") {            \
+    constrained_problems += 1;                             \
+    if (Solve<ceres::examples::TestProblem##n>(true, 0)) { \
+      constrained_successes += 1;                          \
+      ss << "Yes ";                                        \
+    } else {                                               \
+      ss << "No  ";                                        \
+    }                                                      \
+  }                                                        \
   ss << std::endl;
 
   CONSTRAINED_SOLVE(3);
@@ -664,10 +666,8 @@ int main(int argc, char** argv) {
   CONSTRAINED_SOLVE(14);
   CONSTRAINED_SOLVE(16);
   CONSTRAINED_SOLVE(18);
-  ss << "Constrained : "
-     << constrained_successes
-     << "/"
-     << constrained_problems << std::endl;
+  ss << "Constrained : " << constrained_successes << "/" << constrained_problems
+     << std::endl;
 
   std::cout << ss.str();
   return 0;
